@@ -1,20 +1,16 @@
-#!/usr/bin/perl
+use strict;
+use warnings;
+package POE::Component::Supervisor; # git description: 0.08-14-g6e2e02b
 
-package POE::Component::Supervisor;
-use MooseX::POE;
+our $VERSION = '0.09';
 
+use MooseX::POE 0.210;
 use Moose::Util::TypeConstraints;
-
 use POE::Component::Supervisor::Supervised;
 use POE::Component::Supervisor::Handle;
-
 use Devel::PartialDump;
-
 use Hash::Util::FieldHash::Compat qw(idhash);
-
-use namespace::clean -except => 'meta';
-
-our $VERSION = "0.08";
+use namespace::autoclean;
 
 with qw(
     POE::Component::Supervisor::Interface
@@ -31,7 +27,7 @@ sub run {
 sub _build_alias { undef }
 
 has restart_policy => (
-    isa => enum(__PACKAGE__ . "::RestartPolicy" => qw(one all rest)),
+    isa => enum(__PACKAGE__ . "::RestartPolicy" => [qw(one all rest)]),
     is  => "rw",
     default => "one",
 );
@@ -369,7 +365,7 @@ event _child => sub {
     $self->logger->debug("supervisor $self had child event for $child: $verb");
 };
 
-__PACKAGE__
+__PACKAGE__->meta->make_immutable;
 
 __END__
 
@@ -377,7 +373,11 @@ __END__
 
 =head1 NAME
 
-POE::Component::Supervisor - Erlang inspired babysitting
+POE::Component::Supervisor - Erlang-inspired babysitting
+
+=head1 VERSION
+
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -414,6 +414,8 @@ A handle will do the actual management of the child, sending events to the
 supervisor when the child is terminated, and also facilitate explicit
 termination of the child's instance.
 
+=for stopwords respawn
+
 Based on its C<restart_policy> the supervisor may order other handles to also
 stop, and ask various child descriptors to respawn certain children.
 
@@ -473,6 +475,8 @@ The order of the children matters, see C<restart_policy>.
 
 =head1 METHODS
 
+=over 4
+
 =item new %args
 
 =item start @children
@@ -497,10 +501,12 @@ implemented using this method.
 
 If C<true> is returned an error will be thrown by the supervisor.
 
+=back
+
 =head1 EVENTS
 
-The L<POE> event api is currently internal. All manipulation of the supervisor
-object should be done using the api described in L<METHODS>.
+The L<POE> event API is currently internal. All manipulation of the supervisor
+object should be done using the API described in L<METHODS>.
 
 =head1 SEE ALSO
 
