@@ -1,9 +1,9 @@
-#!/usr/bin/perl
-
 package POE::Component::Supervisor::Handle::Interface;
-use Moose::Role;
 
-use namespace::clean -except => 'meta';
+our $VERSION = '0.09';
+
+use Moose::Role;
+use namespace::autoclean;
 
 requires qw(
     stop
