@@ -1,9 +1,9 @@
-#!/usr/bin/perl
-
 package POE::Component::Supervisor::LogDispatch;
-use Moose::Role;
 
-use namespace::clean -except => 'meta';
+our $VERSION = '0.09';
+
+use Moose::Role;
+use namespace::autoclean;
 
 with qw(MooseX::LogDispatch);
 
@@ -26,6 +26,10 @@ __END__
 
 POE::Component::Supervisor::LogDispatch - Logging role
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
     with qw(POE::Component::Supervisor::LogDispatch);
@@ -36,5 +40,3 @@ This is a variation on L<MooseX::LogDispatch> that ensures that a global
 L<Log::Dispatch::Config> singleton will be respected.
 
 =cut
-
-
